EntryCommands

Struct EntryCommands 

pub struct EntryCommands {
    pub create_instance: PFN_vkCreateInstance,
    pub enumerate_instance_version: PFN_vkEnumerateInstanceVersion,
    pub enumerate_instance_layer_properties: PFN_vkEnumerateInstanceLayerProperties,
    pub enumerate_instance_extension_properties: PFN_vkEnumerateInstanceExtensionProperties,
    pub get_external_compute_queue_data_nv: PFN_vkGetExternalComputeQueueDataNV,
}

Fields

create_instance: PFN_vkCreateInstanceenumerate_instance_version: PFN_vkEnumerateInstanceVersionenumerate_instance_layer_properties: PFN_vkEnumerateInstanceLayerPropertiesenumerate_instance_extension_properties: PFN_vkEnumerateInstanceExtensionPropertiesget_external_compute_queue_data_nv: PFN_vkGetExternalComputeQueueDataNV

Implementations

Source

impl EntryCommands

pub unsafe fn load(f: impl FnMut(&CStr) -> *const c_void) -> Self

Load all function pointers from the given loader callback.

Load all function pointers from the given loader callback.

Safety

The loader must return valid function pointers compatible with each command’s signature, or null for unavailable commands.