pub struct ImageLayout(/* private fields */);Expand description
Implementations
Sourceimpl ImageLayout
impl ImageLayout
Sourcepub const UNDEFINED: Self
pub const UNDEFINED: Self
Implicit layout an image is when its contents are undefined due to various reasons (e.g. right after creation)
Sourcepub const COLOR_ATTACHMENT_OPTIMAL: Self
pub const COLOR_ATTACHMENT_OPTIMAL: Self
Optimal layout when image is only used for color attachment read/write
Sourcepub const DEPTH_STENCIL_ATTACHMENT_OPTIMAL: Self
pub const DEPTH_STENCIL_ATTACHMENT_OPTIMAL: Self
Optimal layout when image is only used for depth/stencil attachment read/write
Sourcepub const DEPTH_STENCIL_READ_ONLY_OPTIMAL: Self
pub const DEPTH_STENCIL_READ_ONLY_OPTIMAL: Self
Optimal layout when image is used for read only depth/stencil attachment and shader access
Sourcepub const SHADER_READ_ONLY_OPTIMAL: Self
pub const SHADER_READ_ONLY_OPTIMAL: Self
Optimal layout when image is used for read only shader access
Sourcepub const TRANSFER_SRC_OPTIMAL: Self
pub const TRANSFER_SRC_OPTIMAL: Self
Optimal layout when image is used only as source of transfer operations
Sourcepub const TRANSFER_DST_OPTIMAL: Self
pub const TRANSFER_DST_OPTIMAL: Self
Optimal layout when image is used only as destination of transfer operations
Sourcepub const PREINITIALIZED: Self
pub const PREINITIALIZED: Self
Initial layout used when the data is populated by the CPU
pub const DEPTH_READ_ONLY_STENCIL_ATTACHMENT_OPTIMAL: Self
pub const DEPTH_ATTACHMENT_STENCIL_READ_ONLY_OPTIMAL: Self
pub const DEPTH_ATTACHMENT_OPTIMAL: Self
pub const DEPTH_READ_ONLY_OPTIMAL: Self
pub const STENCIL_ATTACHMENT_OPTIMAL: Self
pub const STENCIL_READ_ONLY_OPTIMAL: Self
pub const READ_ONLY_OPTIMAL: Self
pub const ATTACHMENT_OPTIMAL: Self
pub const RENDERING_LOCAL_READ: Self
pub const PRESENT_SRC: Self
pub const VIDEO_DECODE_DST: Self
pub const VIDEO_DECODE_SRC: Self
pub const VIDEO_DECODE_DPB: Self
pub const SHARED_PRESENT: Self
pub const SHADING_RATE_OPTIMAL: Self = Self::FRAGMENT_SHADING_RATE_ATTACHMENT_OPTIMAL
pub const FRAGMENT_DENSITY_MAP_OPTIMAL: Self
pub const FRAGMENT_SHADING_RATE_ATTACHMENT_OPTIMAL: Self
pub const VIDEO_ENCODE_DST: Self
pub const VIDEO_ENCODE_SRC: Self
pub const VIDEO_ENCODE_DPB: Self
pub const ATTACHMENT_FEEDBACK_LOOP_OPTIMAL: Self
pub const TENSOR_ALIASING: Self
pub const VIDEO_ENCODE_QUANTIZATION_MAP: Self
pub const ZERO_INITIALIZED: Self
pub const fn from_raw(value: i32) -> Self
pub const fn as_raw(self) -> i32