pub struct Result(/* private fields */);Expand description
Implementations
Sourceimpl Result
impl Result
Sourcepub const EVENT_RESET: Self
pub const EVENT_RESET: Self
An event is unsignaled
Sourcepub const INCOMPLETE: Self
pub const INCOMPLETE: Self
A return array was too small for the result
Sourcepub const ERROR_OUT_OF_HOST_MEMORY: Self
pub const ERROR_OUT_OF_HOST_MEMORY: Self
A host memory allocation has failed
Sourcepub const ERROR_OUT_OF_DEVICE_MEMORY: Self
pub const ERROR_OUT_OF_DEVICE_MEMORY: Self
A device memory allocation has failed
Sourcepub const ERROR_INITIALIZATION_FAILED: Self
pub const ERROR_INITIALIZATION_FAILED: Self
Initialization of an object has failed
Sourcepub const ERROR_DEVICE_LOST: Self
pub const ERROR_DEVICE_LOST: Self
The logical device has been lost. See devsandqueues-lost-device
Sourcepub const ERROR_MEMORY_MAP_FAILED: Self
pub const ERROR_MEMORY_MAP_FAILED: Self
Mapping of a memory object has failed
Sourcepub const ERROR_LAYER_NOT_PRESENT: Self
pub const ERROR_LAYER_NOT_PRESENT: Self
Layer specified does not exist
Sourcepub const ERROR_EXTENSION_NOT_PRESENT: Self
pub const ERROR_EXTENSION_NOT_PRESENT: Self
Extension specified does not exist
Sourcepub const ERROR_FEATURE_NOT_PRESENT: Self
pub const ERROR_FEATURE_NOT_PRESENT: Self
Requested feature is not available on this device
Sourcepub const ERROR_INCOMPATIBLE_DRIVER: Self
pub const ERROR_INCOMPATIBLE_DRIVER: Self
Unable to find a Vulkan driver
Sourcepub const ERROR_TOO_MANY_OBJECTS: Self
pub const ERROR_TOO_MANY_OBJECTS: Self
Too many objects of the type have already been created
Sourcepub const ERROR_FORMAT_NOT_SUPPORTED: Self
pub const ERROR_FORMAT_NOT_SUPPORTED: Self
Requested format is not supported on this device
Sourcepub const ERROR_FRAGMENTED_POOL: Self
pub const ERROR_FRAGMENTED_POOL: Self
A requested pool allocation has failed due to fragmentation of the pool’s memory
Sourcepub const ERROR_UNKNOWN: Self
pub const ERROR_UNKNOWN: Self
An unknown error has occurred, due to an implementation or application bug
pub const ERROR_VALIDATION_FAILED: Self
pub const ERROR_OUT_OF_POOL_MEMORY: Self
pub const ERROR_INVALID_EXTERNAL_HANDLE: Self
pub const ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS: Self
pub const ERROR_FRAGMENTATION: Self
pub const PIPELINE_COMPILE_REQUIRED: Self
pub const ERROR_NOT_PERMITTED: Self
pub const ERROR_INVALID_PIPELINE_CACHE_DATA: Self
pub const ERROR_NO_PIPELINE_MATCH: Self
pub const ERROR_SURFACE_LOST: Self
pub const ERROR_NATIVE_WINDOW_IN_USE: Self
pub const SUBOPTIMAL: Self
pub const ERROR_OUT_OF_DATE: Self
pub const ERROR_INCOMPATIBLE_DISPLAY: Self
pub const ERROR_INVALID_SHADER: Self
pub const ERROR_IMAGE_USAGE_NOT_SUPPORTED: Self
pub const ERROR_VIDEO_PICTURE_LAYOUT_NOT_SUPPORTED: Self
pub const ERROR_VIDEO_PROFILE_OPERATION_NOT_SUPPORTED: Self
pub const ERROR_VIDEO_PROFILE_FORMAT_NOT_SUPPORTED: Self
pub const ERROR_VIDEO_PROFILE_CODEC_NOT_SUPPORTED: Self
pub const ERROR_VIDEO_STD_VERSION_NOT_SUPPORTED: Self
pub const ERROR_INVALID_DRM_FORMAT_MODIFIER_PLANE_LAYOUT: Self
pub const ERROR_PRESENT_TIMING_QUEUE_FULL: Self
pub const ERROR_INVALID_DEVICE_ADDRESS: Self = Self::ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS
pub const ERROR_FULL_SCREEN_EXCLUSIVE_MODE_LOST: Self
pub const THREAD_IDLE: Self
pub const THREAD_DONE: Self
pub const OPERATION_DEFERRED: Self
pub const OPERATION_NOT_DEFERRED: Self
pub const ERROR_PIPELINE_COMPILE_REQUIRED: Self = Self::PIPELINE_COMPILE_REQUIRED
pub const ERROR_INVALID_VIDEO_STD_PARAMETERS: Self
pub const ERROR_COMPRESSION_EXHAUSTED: Self
pub const INCOMPATIBLE_SHADER_BINARY: Self
pub const ERROR_INCOMPATIBLE_SHADER_BINARY: Self = Self::INCOMPATIBLE_SHADER_BINARY
pub const PIPELINE_BINARY_MISSING: Self
pub const ERROR_NOT_ENOUGH_SPACE: Self
pub const fn from_raw(value: i32) -> Self
pub const fn as_raw(self) -> i32