pub unsafe trait ExtendsDependencyInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
DependencyInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDependencyInfo { }Marker trait for structs that can appear in the pNext chain of
DependencyInfo.
Implementors must be valid pNext chain members for the target struct.