pub unsafe trait ExtendsDescriptorGetInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
DescriptorGetInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDescriptorGetInfoEXT { }Marker trait for structs that can appear in the pNext chain of
DescriptorGetInfoEXT.
Implementors must be valid pNext chain members for the target struct.