pub unsafe trait ExtendsDeviceEventInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
DeviceEventInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDeviceEventInfoEXT { }Marker trait for structs that can appear in the pNext chain of
DeviceEventInfoEXT.
Implementors must be valid pNext chain members for the target struct.