pub unsafe trait ExtendsDisplayPresentInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
DisplayPresentInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDisplayPresentInfoKHR { }Marker trait for structs that can appear in the pNext chain of
DisplayPresentInfoKHR.
Implementors must be valid pNext chain members for the target struct.