pub unsafe trait ExtendsFaultCallbackInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
FaultCallbackInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsFaultCallbackInfo { }Marker trait for structs that can appear in the pNext chain of
FaultCallbackInfo.
Implementors must be valid pNext chain members for the target struct.