pub unsafe trait ExtendsFrameBoundaryEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
FrameBoundaryEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsFrameBoundaryEXT { }Marker trait for structs that can appear in the pNext chain of
FrameBoundaryEXT.
Implementors must be valid pNext chain members for the target struct.