pub unsafe trait ExtendsImageViewMinLodCreateInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageViewMinLodCreateInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageViewMinLodCreateInfoEXT { }Marker trait for structs that can appear in the pNext chain of
ImageViewMinLodCreateInfoEXT.
Implementors must be valid pNext chain members for the target struct.