pub unsafe trait ExtendsImportMemoryFdInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImportMemoryFdInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImportMemoryFdInfoKHR { }Marker trait for structs that can appear in the pNext chain of
ImportMemoryFdInfoKHR.
Implementors must be valid pNext chain members for the target struct.