pub unsafe trait ExtendsImportNativeBufferInfoOHOS { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImportNativeBufferInfoOHOS.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImportNativeBufferInfoOHOS { }Marker trait for structs that can appear in the pNext chain of
ImportNativeBufferInfoOHOS.
Implementors must be valid pNext chain members for the target struct.