pub unsafe trait ExtendsPipelineCreateInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
PipelineCreateInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPipelineCreateInfoKHR { }Marker trait for structs that can appear in the pNext chain of
PipelineCreateInfoKHR.
Implementors must be valid pNext chain members for the target struct.