pub unsafe trait ExtendsPipelineExecutableInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
PipelineExecutableInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPipelineExecutableInfoKHR { }Marker trait for structs that can appear in the pNext chain of
PipelineExecutableInfoKHR.
Implementors must be valid pNext chain members for the target struct.