pub unsafe trait ExtendsTimelineSemaphoreSubmitInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
TimelineSemaphoreSubmitInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTimelineSemaphoreSubmitInfo { }Marker trait for structs that can appear in the pNext chain of
TimelineSemaphoreSubmitInfo.
Implementors must be valid pNext chain members for the target struct.