pub unsafe trait ExtendsVideoDecodeAV1ProfileInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoDecodeAV1ProfileInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoDecodeAV1ProfileInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoDecodeAV1ProfileInfoKHR.
Implementors must be valid pNext chain members for the target struct.