pub unsafe trait ExtendsVideoEncodeAV1DpbSlotInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoEncodeAV1DpbSlotInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoEncodeAV1DpbSlotInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoEncodeAV1DpbSlotInfoKHR.
Implementors must be valid pNext chain members for the target struct.