pub unsafe trait ExtendsVideoProfileInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoProfileInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoProfileInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoProfileInfoKHR.
Implementors must be valid pNext chain members for the target struct.