pub unsafe trait ExtendsVideoProfileListInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoProfileListInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoProfileListInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoProfileListInfoKHR.
Implementors must be valid pNext chain members for the target struct.