pub unsafe trait ExtendsXcbSurfaceCreateInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
XcbSurfaceCreateInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsXcbSurfaceCreateInfoKHR { }Marker trait for structs that can appear in the pNext chain of
XcbSurfaceCreateInfoKHR.
Implementors must be valid pNext chain members for the target struct.