pub unsafe trait ExtendsAcquireProfilingLockInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
AcquireProfilingLockInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsAcquireProfilingLockInfoKHR { }Marker trait for structs that can appear in the pNext chain of
AcquireProfilingLockInfoKHR.
Implementors must be valid pNext chain members for the target struct.