pub unsafe trait ExtendsAntiLagPresentationInfoAMD { }Expand description
Marker trait for structs that can appear in the pNext chain of
AntiLagPresentationInfoAMD.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsAntiLagPresentationInfoAMD { }Marker trait for structs that can appear in the pNext chain of
AntiLagPresentationInfoAMD.
Implementors must be valid pNext chain members for the target struct.