pub unsafe trait ExtendsAttachmentDescription2 { }Expand description
Marker trait for structs that can appear in the pNext chain of
AttachmentDescription2.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsAttachmentDescription2 { }Marker trait for structs that can appear in the pNext chain of
AttachmentDescription2.
Implementors must be valid pNext chain members for the target struct.