pub unsafe trait ExtendsAttachmentReference2 { }Expand description
Marker trait for structs that can appear in the pNext chain of
AttachmentReference2.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsAttachmentReference2 { }Marker trait for structs that can appear in the pNext chain of
AttachmentReference2.
Implementors must be valid pNext chain members for the target struct.