pub unsafe trait ExtendsBeginCustomResolveInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
BeginCustomResolveInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBeginCustomResolveInfoEXT { }Marker trait for structs that can appear in the pNext chain of
BeginCustomResolveInfoEXT.
Implementors must be valid pNext chain members for the target struct.