pub unsafe trait ExtendsBindBufferMemoryInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
BindBufferMemoryInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBindBufferMemoryInfo { }Marker trait for structs that can appear in the pNext chain of
BindBufferMemoryInfo.
Implementors must be valid pNext chain members for the target struct.