pub unsafe trait ExtendsBindDescriptorSetsInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
BindDescriptorSetsInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBindDescriptorSetsInfo { }Marker trait for structs that can appear in the pNext chain of
BindDescriptorSetsInfo.
Implementors must be valid pNext chain members for the target struct.