pub unsafe trait ExtendsBindHeapInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
BindHeapInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBindHeapInfoEXT { }Marker trait for structs that can appear in the pNext chain of
BindHeapInfoEXT.
Implementors must be valid pNext chain members for the target struct.