pub unsafe trait ExtendsBindImageMemoryInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
BindImageMemoryInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBindImageMemoryInfo { }Marker trait for structs that can appear in the pNext chain of
BindImageMemoryInfo.
Implementors must be valid pNext chain members for the target struct.