pub unsafe trait ExtendsBindImagePlaneMemoryInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
BindImagePlaneMemoryInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBindImagePlaneMemoryInfo { }Marker trait for structs that can appear in the pNext chain of
BindImagePlaneMemoryInfo.
Implementors must be valid pNext chain members for the target struct.