pub unsafe trait ExtendsBindIndexBuffer3InfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
BindIndexBuffer3InfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBindIndexBuffer3InfoKHR { }Marker trait for structs that can appear in the pNext chain of
BindIndexBuffer3InfoKHR.
Implementors must be valid pNext chain members for the target struct.