pub unsafe trait ExtendsBindMemoryStatus { }Expand description
Marker trait for structs that can appear in the pNext chain of
BindMemoryStatus.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBindMemoryStatus { }Marker trait for structs that can appear in the pNext chain of
BindMemoryStatus.
Implementors must be valid pNext chain members for the target struct.