pub unsafe trait ExtendsBindTensorMemoryInfoARM { }Expand description
Marker trait for structs that can appear in the pNext chain of
BindTensorMemoryInfoARM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBindTensorMemoryInfoARM { }Marker trait for structs that can appear in the pNext chain of
BindTensorMemoryInfoARM.
Implementors must be valid pNext chain members for the target struct.