pub unsafe trait ExtendsBindVertexBuffer3InfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
BindVertexBuffer3InfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBindVertexBuffer3InfoKHR { }Marker trait for structs that can appear in the pNext chain of
BindVertexBuffer3InfoKHR.
Implementors must be valid pNext chain members for the target struct.