pub unsafe trait ExtendsBufferDeviceAddressInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
BufferDeviceAddressInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBufferDeviceAddressInfo { }Marker trait for structs that can appear in the pNext chain of
BufferDeviceAddressInfo.
Implementors must be valid pNext chain members for the target struct.