pub unsafe trait ExtendsBufferUsageFlags2CreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
BufferUsageFlags2CreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBufferUsageFlags2CreateInfo { }Marker trait for structs that can appear in the pNext chain of
BufferUsageFlags2CreateInfo.
Implementors must be valid pNext chain members for the target struct.