pub unsafe trait ExtendsBufferViewCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
BufferViewCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsBufferViewCreateInfo { }Marker trait for structs that can appear in the pNext chain of
BufferViewCreateInfo.
Implementors must be valid pNext chain members for the target struct.