pub unsafe trait ExtendsCalibratedTimestampInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
CalibratedTimestampInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCalibratedTimestampInfoKHR { }Marker trait for structs that can appear in the pNext chain of
CalibratedTimestampInfoKHR.
Implementors must be valid pNext chain members for the target struct.