pub unsafe trait ExtendsCommandBufferInheritanceInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
CommandBufferInheritanceInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCommandBufferInheritanceInfo { }Marker trait for structs that can appear in the pNext chain of
CommandBufferInheritanceInfo.
Implementors must be valid pNext chain members for the target struct.