pub unsafe trait ExtendsCommandPoolCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
CommandPoolCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCommandPoolCreateInfo { }Marker trait for structs that can appear in the pNext chain of
CommandPoolCreateInfo.
Implementors must be valid pNext chain members for the target struct.