pub unsafe trait ExtendsCopyDeviceMemoryInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
CopyDeviceMemoryInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCopyDeviceMemoryInfoKHR { }Marker trait for structs that can appear in the pNext chain of
CopyDeviceMemoryInfoKHR.
Implementors must be valid pNext chain members for the target struct.