pub unsafe trait ExtendsCopyTensorInfoARM { }Expand description
Marker trait for structs that can appear in the pNext chain of
CopyTensorInfoARM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCopyTensorInfoARM { }Marker trait for structs that can appear in the pNext chain of
CopyTensorInfoARM.
Implementors must be valid pNext chain members for the target struct.