pub unsafe trait ExtendsCuLaunchInfoNVX { }Expand description
Marker trait for structs that can appear in the pNext chain of
CuLaunchInfoNVX.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCuLaunchInfoNVX { }Marker trait for structs that can appear in the pNext chain of
CuLaunchInfoNVX.
Implementors must be valid pNext chain members for the target struct.