pub unsafe trait ExtendsCudaLaunchInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
CudaLaunchInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCudaLaunchInfoNV { }Marker trait for structs that can appear in the pNext chain of
CudaLaunchInfoNV.
Implementors must be valid pNext chain members for the target struct.