pub unsafe trait ExtendsCustomResolveCreateInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
CustomResolveCreateInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsCustomResolveCreateInfoEXT { }Marker trait for structs that can appear in the pNext chain of
CustomResolveCreateInfoEXT.
Implementors must be valid pNext chain members for the target struct.