pub unsafe trait ExtendsDepthBiasInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
DepthBiasInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDepthBiasInfoEXT { }Marker trait for structs that can appear in the pNext chain of
DepthBiasInfoEXT.
Implementors must be valid pNext chain members for the target struct.