pub unsafe trait ExtendsDescriptorAddressInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
DescriptorAddressInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDescriptorAddressInfoEXT { }Marker trait for structs that can appear in the pNext chain of
DescriptorAddressInfoEXT.
Implementors must be valid pNext chain members for the target struct.