pub unsafe trait ExtendsDescriptorGetTensorInfoARM { }Expand description
Marker trait for structs that can appear in the pNext chain of
DescriptorGetTensorInfoARM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDescriptorGetTensorInfoARM { }Marker trait for structs that can appear in the pNext chain of
DescriptorGetTensorInfoARM.
Implementors must be valid pNext chain members for the target struct.