pub unsafe trait ExtendsDeviceGroupSubmitInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
DeviceGroupSubmitInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDeviceGroupSubmitInfo { }Marker trait for structs that can appear in the pNext chain of
DeviceGroupSubmitInfo.
Implementors must be valid pNext chain members for the target struct.