pub unsafe trait ExtendsDirectFBSurfaceCreateInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
DirectFBSurfaceCreateInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDirectFBSurfaceCreateInfoEXT { }Marker trait for structs that can appear in the pNext chain of
DirectFBSurfaceCreateInfoEXT.
Implementors must be valid pNext chain members for the target struct.