pub unsafe trait ExtendsDispatchIndirect2InfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
DispatchIndirect2InfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDispatchIndirect2InfoKHR { }Marker trait for structs that can appear in the pNext chain of
DispatchIndirect2InfoKHR.
Implementors must be valid pNext chain members for the target struct.