pub unsafe trait ExtendsDispatchTileInfoQCOM { }Expand description
Marker trait for structs that can appear in the pNext chain of
DispatchTileInfoQCOM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDispatchTileInfoQCOM { }Marker trait for structs that can appear in the pNext chain of
DispatchTileInfoQCOM.
Implementors must be valid pNext chain members for the target struct.