pub unsafe trait ExtendsDisplayEventInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
DisplayEventInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDisplayEventInfoEXT { }Marker trait for structs that can appear in the pNext chain of
DisplayEventInfoEXT.
Implementors must be valid pNext chain members for the target struct.