pub unsafe trait ExtendsDisplayModeProperties2KHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
DisplayModeProperties2KHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDisplayModeProperties2KHR { }Marker trait for structs that can appear in the pNext chain of
DisplayModeProperties2KHR.
Implementors must be valid pNext chain members for the target struct.