pub unsafe trait ExtendsDisplayPlaneInfo2KHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
DisplayPlaneInfo2KHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDisplayPlaneInfo2KHR { }Marker trait for structs that can appear in the pNext chain of
DisplayPlaneInfo2KHR.
Implementors must be valid pNext chain members for the target struct.