pub unsafe trait ExtendsDisplayPowerInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
DisplayPowerInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDisplayPowerInfoEXT { }Marker trait for structs that can appear in the pNext chain of
DisplayPowerInfoEXT.
Implementors must be valid pNext chain members for the target struct.