pub unsafe trait ExtendsDrawIndirect2InfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
DrawIndirect2InfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDrawIndirect2InfoKHR { }Marker trait for structs that can appear in the pNext chain of
DrawIndirect2InfoKHR.
Implementors must be valid pNext chain members for the target struct.