pub unsafe trait ExtendsDrawIndirectCount2InfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
DrawIndirectCount2InfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsDrawIndirectCount2InfoKHR { }Marker trait for structs that can appear in the pNext chain of
DrawIndirectCount2InfoKHR.
Implementors must be valid pNext chain members for the target struct.