pub unsafe trait ExtendsEventCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
EventCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsEventCreateInfo { }Marker trait for structs that can appear in the pNext chain of
EventCreateInfo.
Implementors must be valid pNext chain members for the target struct.