pub unsafe trait ExtendsExportFenceCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExportFenceCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExportFenceCreateInfo { }Marker trait for structs that can appear in the pNext chain of
ExportFenceCreateInfo.
Implementors must be valid pNext chain members for the target struct.