pub unsafe trait ExtendsExportMemoryAllocateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExportMemoryAllocateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExportMemoryAllocateInfo { }Marker trait for structs that can appear in the pNext chain of
ExportMemoryAllocateInfo.
Implementors must be valid pNext chain members for the target struct.