pub unsafe trait ExtendsExportMemoryAllocateInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExportMemoryAllocateInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExportMemoryAllocateInfoNV { }Marker trait for structs that can appear in the pNext chain of
ExportMemoryAllocateInfoNV.
Implementors must be valid pNext chain members for the target struct.