pub unsafe trait ExtendsExportMemorySciBufInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExportMemorySciBufInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExportMemorySciBufInfoNV { }Marker trait for structs that can appear in the pNext chain of
ExportMemorySciBufInfoNV.
Implementors must be valid pNext chain members for the target struct.