pub unsafe trait ExtendsExportMetalBufferInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExportMetalBufferInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExportMetalBufferInfoEXT { }Marker trait for structs that can appear in the pNext chain of
ExportMetalBufferInfoEXT.
Implementors must be valid pNext chain members for the target struct.