pub unsafe trait ExtendsExportMetalDeviceInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExportMetalDeviceInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExportMetalDeviceInfoEXT { }Marker trait for structs that can appear in the pNext chain of
ExportMetalDeviceInfoEXT.
Implementors must be valid pNext chain members for the target struct.