pub unsafe trait ExtendsExportMetalTextureInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExportMetalTextureInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExportMetalTextureInfoEXT { }Marker trait for structs that can appear in the pNext chain of
ExportMetalTextureInfoEXT.
Implementors must be valid pNext chain members for the target struct.