pub unsafe trait ExtendsExternalFormatQNX { }Expand description
Marker trait for structs that can appear in the pNext chain of
ExternalFormatQNX.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsExternalFormatQNX { }Marker trait for structs that can appear in the pNext chain of
ExternalFormatQNX.
Implementors must be valid pNext chain members for the target struct.