pub unsafe trait ExtendsFenceGetFdInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
FenceGetFdInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsFenceGetFdInfoKHR { }Marker trait for structs that can appear in the pNext chain of
FenceGetFdInfoKHR.
Implementors must be valid pNext chain members for the target struct.