pub unsafe trait ExtendsFenceGetWin32HandleInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
FenceGetWin32HandleInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsFenceGetWin32HandleInfoKHR { }Marker trait for structs that can appear in the pNext chain of
FenceGetWin32HandleInfoKHR.
Implementors must be valid pNext chain members for the target struct.