pub unsafe trait ExtendsGeometryAABBNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
GeometryAABBNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsGeometryAABBNV { }Marker trait for structs that can appear in the pNext chain of
GeometryAABBNV.
Implementors must be valid pNext chain members for the target struct.