pub unsafe trait ExtendsGeometryNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
GeometryNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsGeometryNV { }Marker trait for structs that can appear in the pNext chain of
GeometryNV.
Implementors must be valid pNext chain members for the target struct.