pub unsafe trait ExtendsGraphicsPipelineCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
GraphicsPipelineCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsGraphicsPipelineCreateInfo { }Marker trait for structs that can appear in the pNext chain of
GraphicsPipelineCreateInfo.
Implementors must be valid pNext chain members for the target struct.