pub unsafe trait ExtendsIOSSurfaceCreateInfoMVK { }Expand description
Marker trait for structs that can appear in the pNext chain of
IOSSurfaceCreateInfoMVK.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsIOSSurfaceCreateInfoMVK { }Marker trait for structs that can appear in the pNext chain of
IOSSurfaceCreateInfoMVK.
Implementors must be valid pNext chain members for the target struct.