pub unsafe trait ExtendsImageBlit2 { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageBlit2.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageBlit2 { }Marker trait for structs that can appear in the pNext chain of
ImageBlit2.
Implementors must be valid pNext chain members for the target struct.