pub unsafe trait ExtendsImageDescriptorInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageDescriptorInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageDescriptorInfoEXT { }Marker trait for structs that can appear in the pNext chain of
ImageDescriptorInfoEXT.
Implementors must be valid pNext chain members for the target struct.