pub unsafe trait ExtendsImageMemoryBarrier2 { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageMemoryBarrier2.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageMemoryBarrier2 { }Marker trait for structs that can appear in the pNext chain of
ImageMemoryBarrier2.
Implementors must be valid pNext chain members for the target struct.