pub unsafe trait ExtendsImageSubresource2 { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImageSubresource2.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImageSubresource2 { }Marker trait for structs that can appear in the pNext chain of
ImageSubresource2.
Implementors must be valid pNext chain members for the target struct.