pub unsafe trait ExtendsImportFenceFdInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImportFenceFdInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImportFenceFdInfoKHR { }Marker trait for structs that can appear in the pNext chain of
ImportFenceFdInfoKHR.
Implementors must be valid pNext chain members for the target struct.