pub unsafe trait ExtendsImportMemorySciBufInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImportMemorySciBufInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImportMemorySciBufInfoNV { }Marker trait for structs that can appear in the pNext chain of
ImportMemorySciBufInfoNV.
Implementors must be valid pNext chain members for the target struct.