pub unsafe trait ExtendsImportMetalBufferInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImportMetalBufferInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImportMetalBufferInfoEXT { }Marker trait for structs that can appear in the pNext chain of
ImportMetalBufferInfoEXT.
Implementors must be valid pNext chain members for the target struct.