pub unsafe trait ExtendsImportScreenBufferInfoQNX { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImportScreenBufferInfoQNX.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImportScreenBufferInfoQNX { }Marker trait for structs that can appear in the pNext chain of
ImportScreenBufferInfoQNX.
Implementors must be valid pNext chain members for the target struct.