pub unsafe trait ExtendsImportSemaphoreFdInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
ImportSemaphoreFdInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsImportSemaphoreFdInfoKHR { }Marker trait for structs that can appear in the pNext chain of
ImportSemaphoreFdInfoKHR.
Implementors must be valid pNext chain members for the target struct.