pub unsafe trait ExtendsLatencySleepModeInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
LatencySleepModeInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsLatencySleepModeInfoNV { }Marker trait for structs that can appear in the pNext chain of
LatencySleepModeInfoNV.
Implementors must be valid pNext chain members for the target struct.