pub unsafe trait ExtendsLatencySurfaceCapabilitiesNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
LatencySurfaceCapabilitiesNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsLatencySurfaceCapabilitiesNV { }Marker trait for structs that can appear in the pNext chain of
LatencySurfaceCapabilitiesNV.
Implementors must be valid pNext chain members for the target struct.