pub unsafe trait ExtendsMemoryAllocateFlagsInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryAllocateFlagsInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryAllocateFlagsInfo { }Marker trait for structs that can appear in the pNext chain of
MemoryAllocateFlagsInfo.
Implementors must be valid pNext chain members for the target struct.