pub unsafe trait ExtendsMemoryAllocateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryAllocateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryAllocateInfo { }Marker trait for structs that can appear in the pNext chain of
MemoryAllocateInfo.
Implementors must be valid pNext chain members for the target struct.