pub unsafe trait ExtendsMemoryBarrier2 { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryBarrier2.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryBarrier2 { }Marker trait for structs that can appear in the pNext chain of
MemoryBarrier2.
Implementors must be valid pNext chain members for the target struct.