pub unsafe trait ExtendsMemoryGetMetalHandleInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryGetMetalHandleInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryGetMetalHandleInfoEXT { }Marker trait for structs that can appear in the pNext chain of
MemoryGetMetalHandleInfoEXT.
Implementors must be valid pNext chain members for the target struct.