pub unsafe trait ExtendsMemoryGetSciBufInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryGetSciBufInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryGetSciBufInfoNV { }Marker trait for structs that can appear in the pNext chain of
MemoryGetSciBufInfoNV.
Implementors must be valid pNext chain members for the target struct.