pub unsafe trait ExtendsMemoryMapPlacedInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryMapPlacedInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryMapPlacedInfoEXT { }Marker trait for structs that can appear in the pNext chain of
MemoryMapPlacedInfoEXT.
Implementors must be valid pNext chain members for the target struct.