pub unsafe trait ExtendsMemorySciBufPropertiesNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemorySciBufPropertiesNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemorySciBufPropertiesNV { }Marker trait for structs that can appear in the pNext chain of
MemorySciBufPropertiesNV.
Implementors must be valid pNext chain members for the target struct.