pub unsafe trait ExtendsMemoryUnmapInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
MemoryUnmapInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMemoryUnmapInfo { }Marker trait for structs that can appear in the pNext chain of
MemoryUnmapInfo.
Implementors must be valid pNext chain members for the target struct.