pub unsafe trait ExtendsMetalSurfaceCreateInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
MetalSurfaceCreateInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMetalSurfaceCreateInfoEXT { }Marker trait for structs that can appear in the pNext chain of
MetalSurfaceCreateInfoEXT.
Implementors must be valid pNext chain members for the target struct.