pub unsafe trait ExtendsMicromapBuildInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
MicromapBuildInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMicromapBuildInfoEXT { }Marker trait for structs that can appear in the pNext chain of
MicromapBuildInfoEXT.
Implementors must be valid pNext chain members for the target struct.