pub unsafe trait ExtendsMicromapBuildSizesInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
MicromapBuildSizesInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMicromapBuildSizesInfoEXT { }Marker trait for structs that can appear in the pNext chain of
MicromapBuildSizesInfoEXT.
Implementors must be valid pNext chain members for the target struct.