pub unsafe trait ExtendsMicromapVersionInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
MicromapVersionInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsMicromapVersionInfoEXT { }Marker trait for structs that can appear in the pNext chain of
MicromapVersionInfoEXT.
Implementors must be valid pNext chain members for the target struct.