pub unsafe trait ExtendsNativeBufferOHOS { }Expand description
Marker trait for structs that can appear in the pNext chain of
NativeBufferOHOS.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsNativeBufferOHOS { }Marker trait for structs that can appear in the pNext chain of
NativeBufferOHOS.
Implementors must be valid pNext chain members for the target struct.