pub unsafe trait ExtendsPerformanceMarkerInfoINTEL { }Expand description
Marker trait for structs that can appear in the pNext chain of
PerformanceMarkerInfoINTEL.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPerformanceMarkerInfoINTEL { }Marker trait for structs that can appear in the pNext chain of
PerformanceMarkerInfoINTEL.
Implementors must be valid pNext chain members for the target struct.