pub unsafe trait ExtendsPipelineBinaryInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
PipelineBinaryInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPipelineBinaryInfoKHR { }Marker trait for structs that can appear in the pNext chain of
PipelineBinaryInfoKHR.
Implementors must be valid pNext chain members for the target struct.