pub unsafe trait ExtendsPipelineBinaryKeyKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
PipelineBinaryKeyKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPipelineBinaryKeyKHR { }Marker trait for structs that can appear in the pNext chain of
PipelineBinaryKeyKHR.
Implementors must be valid pNext chain members for the target struct.