pub unsafe trait ExtendsPipelineInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
PipelineInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPipelineInfoKHR { }Marker trait for structs that can appear in the pNext chain of
PipelineInfoKHR.
Implementors must be valid pNext chain members for the target struct.