pub unsafe trait ExtendsPipelineRenderingCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
PipelineRenderingCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPipelineRenderingCreateInfo { }Marker trait for structs that can appear in the pNext chain of
PipelineRenderingCreateInfo.
Implementors must be valid pNext chain members for the target struct.