pub unsafe trait ExtendsPresentIdKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
PresentIdKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPresentIdKHR { }Marker trait for structs that can appear in the pNext chain of
PresentIdKHR.
Implementors must be valid pNext chain members for the target struct.