pub unsafe trait ExtendsPresentInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
PresentInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPresentInfoKHR { }Marker trait for structs that can appear in the pNext chain of
PresentInfoKHR.
Implementors must be valid pNext chain members for the target struct.