pub unsafe trait ExtendsPresentTimingInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
PresentTimingInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPresentTimingInfoEXT { }Marker trait for structs that can appear in the pNext chain of
PresentTimingInfoEXT.
Implementors must be valid pNext chain members for the target struct.