pub unsafe trait ExtendsPushConstantBankInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
PushConstantBankInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPushConstantBankInfoNV { }Marker trait for structs that can appear in the pNext chain of
PushConstantBankInfoNV.
Implementors must be valid pNext chain members for the target struct.