pub unsafe trait ExtendsPushDataInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
PushDataInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsPushDataInfoEXT { }Marker trait for structs that can appear in the pNext chain of
PushDataInfoEXT.
Implementors must be valid pNext chain members for the target struct.