pub unsafe trait ExtendsQueryLowLatencySupportNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
QueryLowLatencySupportNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsQueryLowLatencySupportNV { }Marker trait for structs that can appear in the pNext chain of
QueryLowLatencySupportNV.
Implementors must be valid pNext chain members for the target struct.