pub unsafe trait ExtendsQueueFamilyProperties2 { }Expand description
Marker trait for structs that can appear in the pNext chain of
QueueFamilyProperties2.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsQueueFamilyProperties2 { }Marker trait for structs that can appear in the pNext chain of
QueueFamilyProperties2.
Implementors must be valid pNext chain members for the target struct.