pub unsafe trait ExtendsRenderingAreaInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
RenderingAreaInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsRenderingAreaInfo { }Marker trait for structs that can appear in the pNext chain of
RenderingAreaInfo.
Implementors must be valid pNext chain members for the target struct.