pub unsafe trait ExtendsRenderingAttachmentInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
RenderingAttachmentInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsRenderingAttachmentInfo { }Marker trait for structs that can appear in the pNext chain of
RenderingAttachmentInfo.
Implementors must be valid pNext chain members for the target struct.