pub unsafe trait ExtendsSampleLocationsInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
SampleLocationsInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSampleLocationsInfoEXT { }Marker trait for structs that can appear in the pNext chain of
SampleLocationsInfoEXT.
Implementors must be valid pNext chain members for the target struct.