pub unsafe trait ExtendsSciSyncAttributesInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
SciSyncAttributesInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSciSyncAttributesInfoNV { }Marker trait for structs that can appear in the pNext chain of
SciSyncAttributesInfoNV.
Implementors must be valid pNext chain members for the target struct.