pub unsafe trait ExtendsScreenBufferPropertiesQNX { }Expand description
Marker trait for structs that can appear in the pNext chain of
ScreenBufferPropertiesQNX.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsScreenBufferPropertiesQNX { }Marker trait for structs that can appear in the pNext chain of
ScreenBufferPropertiesQNX.
Implementors must be valid pNext chain members for the target struct.