pub unsafe trait ExtendsSemaphoreCreateInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
SemaphoreCreateInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSemaphoreCreateInfo { }Marker trait for structs that can appear in the pNext chain of
SemaphoreCreateInfo.
Implementors must be valid pNext chain members for the target struct.