pub unsafe trait ExtendsSemaphoreGetFdInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
SemaphoreGetFdInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSemaphoreGetFdInfoKHR { }Marker trait for structs that can appear in the pNext chain of
SemaphoreGetFdInfoKHR.
Implementors must be valid pNext chain members for the target struct.