pub unsafe trait ExtendsSemaphoreSignalInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
SemaphoreSignalInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSemaphoreSignalInfo { }Marker trait for structs that can appear in the pNext chain of
SemaphoreSignalInfo.
Implementors must be valid pNext chain members for the target struct.