pub unsafe trait ExtendsSemaphoreWaitInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
SemaphoreWaitInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSemaphoreWaitInfo { }Marker trait for structs that can appear in the pNext chain of
SemaphoreWaitInfo.
Implementors must be valid pNext chain members for the target struct.