pub unsafe trait ExtendsSetLatencyMarkerInfoNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
SetLatencyMarkerInfoNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSetLatencyMarkerInfoNV { }Marker trait for structs that can appear in the pNext chain of
SetLatencyMarkerInfoNV.
Implementors must be valid pNext chain members for the target struct.