pub unsafe trait ExtendsSetPresentConfigNV { }Expand description
Marker trait for structs that can appear in the pNext chain of
SetPresentConfigNV.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSetPresentConfigNV { }Marker trait for structs that can appear in the pNext chain of
SetPresentConfigNV.
Implementors must be valid pNext chain members for the target struct.