pub unsafe trait ExtendsShaderCreateInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
ShaderCreateInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsShaderCreateInfoEXT { }Marker trait for structs that can appear in the pNext chain of
ShaderCreateInfoEXT.
Implementors must be valid pNext chain members for the target struct.