pub unsafe trait ExtendsSubpassBeginInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
SubpassBeginInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSubpassBeginInfo { }Marker trait for structs that can appear in the pNext chain of
SubpassBeginInfo.
Implementors must be valid pNext chain members for the target struct.