pub unsafe trait ExtendsSubpassEndInfo { }Expand description
Marker trait for structs that can appear in the pNext chain of
SubpassEndInfo.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSubpassEndInfo { }Marker trait for structs that can appear in the pNext chain of
SubpassEndInfo.
Implementors must be valid pNext chain members for the target struct.