pub unsafe trait ExtendsSurfaceFormat2KHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
SurfaceFormat2KHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSurfaceFormat2KHR { }Marker trait for structs that can appear in the pNext chain of
SurfaceFormat2KHR.
Implementors must be valid pNext chain members for the target struct.