pub unsafe trait ExtendsSwapchainPresentModeInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
SwapchainPresentModeInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsSwapchainPresentModeInfoKHR { }Marker trait for structs that can appear in the pNext chain of
SwapchainPresentModeInfoKHR.
Implementors must be valid pNext chain members for the target struct.