pub unsafe trait ExtendsTensorCreateInfoARM { }Expand description
Marker trait for structs that can appear in the pNext chain of
TensorCreateInfoARM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTensorCreateInfoARM { }Marker trait for structs that can appear in the pNext chain of
TensorCreateInfoARM.
Implementors must be valid pNext chain members for the target struct.