pub unsafe trait ExtendsTensorViewCreateInfoARM { }Expand description
Marker trait for structs that can appear in the pNext chain of
TensorViewCreateInfoARM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTensorViewCreateInfoARM { }Marker trait for structs that can appear in the pNext chain of
TensorViewCreateInfoARM.
Implementors must be valid pNext chain members for the target struct.