pub unsafe trait ExtendsTexelBufferDescriptorInfoEXT { }Expand description
Marker trait for structs that can appear in the pNext chain of
TexelBufferDescriptorInfoEXT.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTexelBufferDescriptorInfoEXT { }Marker trait for structs that can appear in the pNext chain of
TexelBufferDescriptorInfoEXT.
Implementors must be valid pNext chain members for the target struct.