pub unsafe trait ExtendsTileMemoryBindInfoQCOM { }Expand description
Marker trait for structs that can appear in the pNext chain of
TileMemoryBindInfoQCOM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTileMemoryBindInfoQCOM { }Marker trait for structs that can appear in the pNext chain of
TileMemoryBindInfoQCOM.
Implementors must be valid pNext chain members for the target struct.