pub unsafe trait ExtendsTilePropertiesQCOM { }Expand description
Marker trait for structs that can appear in the pNext chain of
TilePropertiesQCOM.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsTilePropertiesQCOM { }Marker trait for structs that can appear in the pNext chain of
TilePropertiesQCOM.
Implementors must be valid pNext chain members for the target struct.