pub unsafe trait ExtendsUbmSurfaceCreateInfoSEC { }Expand description
Marker trait for structs that can appear in the pNext chain of
UbmSurfaceCreateInfoSEC.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsUbmSurfaceCreateInfoSEC { }Marker trait for structs that can appear in the pNext chain of
UbmSurfaceCreateInfoSEC.
Implementors must be valid pNext chain members for the target struct.