pub unsafe trait ExtendsViSurfaceCreateInfoNN { }Expand description
Marker trait for structs that can appear in the pNext chain of
ViSurfaceCreateInfoNN.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsViSurfaceCreateInfoNN { }Marker trait for structs that can appear in the pNext chain of
ViSurfaceCreateInfoNN.
Implementors must be valid pNext chain members for the target struct.