pub unsafe trait ExtendsVideoCapabilitiesKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoCapabilitiesKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoCapabilitiesKHR { }Marker trait for structs that can appear in the pNext chain of
VideoCapabilitiesKHR.
Implementors must be valid pNext chain members for the target struct.