pub unsafe trait ExtendsVideoDecodeAV1PictureInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoDecodeAV1PictureInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoDecodeAV1PictureInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoDecodeAV1PictureInfoKHR.
Implementors must be valid pNext chain members for the target struct.