pub unsafe trait ExtendsVideoDecodeInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoDecodeInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoDecodeInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoDecodeInfoKHR.
Implementors must be valid pNext chain members for the target struct.