pub unsafe trait ExtendsVideoDecodeUsageInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoDecodeUsageInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoDecodeUsageInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoDecodeUsageInfoKHR.
Implementors must be valid pNext chain members for the target struct.