pub unsafe trait ExtendsVideoDecodeVP9PictureInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoDecodeVP9PictureInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoDecodeVP9PictureInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoDecodeVP9PictureInfoKHR.
Implementors must be valid pNext chain members for the target struct.