pub unsafe trait ExtendsVideoDecodeVP9ProfileInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoDecodeVP9ProfileInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoDecodeVP9ProfileInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoDecodeVP9ProfileInfoKHR.
Implementors must be valid pNext chain members for the target struct.