pub unsafe trait ExtendsVideoEncodeAV1PictureInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoEncodeAV1PictureInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoEncodeAV1PictureInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoEncodeAV1PictureInfoKHR.
Implementors must be valid pNext chain members for the target struct.