pub unsafe trait ExtendsVideoEncodeAV1ProfileInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoEncodeAV1ProfileInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoEncodeAV1ProfileInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoEncodeAV1ProfileInfoKHR.
Implementors must be valid pNext chain members for the target struct.