pub unsafe trait ExtendsVideoEndCodingInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoEndCodingInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoEndCodingInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoEndCodingInfoKHR.
Implementors must be valid pNext chain members for the target struct.