pub unsafe trait ExtendsVideoInlineQueryInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoInlineQueryInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoInlineQueryInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoInlineQueryInfoKHR.
Implementors must be valid pNext chain members for the target struct.