pub unsafe trait ExtendsVideoPictureResourceInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoPictureResourceInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoPictureResourceInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoPictureResourceInfoKHR.
Implementors must be valid pNext chain members for the target struct.