pub unsafe trait ExtendsVideoReferenceSlotInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
VideoReferenceSlotInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsVideoReferenceSlotInfoKHR { }Marker trait for structs that can appear in the pNext chain of
VideoReferenceSlotInfoKHR.
Implementors must be valid pNext chain members for the target struct.