pub unsafe trait ExtendsWaylandSurfaceCreateInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
WaylandSurfaceCreateInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsWaylandSurfaceCreateInfoKHR { }Marker trait for structs that can appear in the pNext chain of
WaylandSurfaceCreateInfoKHR.
Implementors must be valid pNext chain members for the target struct.