pub unsafe trait ExtendsWin32SurfaceCreateInfoKHR { }Expand description
Marker trait for structs that can appear in the pNext chain of
Win32SurfaceCreateInfoKHR.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsWin32SurfaceCreateInfoKHR { }Marker trait for structs that can appear in the pNext chain of
Win32SurfaceCreateInfoKHR.
Implementors must be valid pNext chain members for the target struct.