pub unsafe trait ExtendsWriteDescriptorSet { }Expand description
Marker trait for structs that can appear in the pNext chain of
WriteDescriptorSet.
Safety
Implementors must be valid pNext chain members for the target struct.
pub unsafe trait ExtendsWriteDescriptorSet { }Marker trait for structs that can appear in the pNext chain of
WriteDescriptorSet.
Implementors must be valid pNext chain members for the target struct.